@@ -83,6 +83,7 @@ class Exporter:
 	def db_to_etree(self, name: str) -> ElementTree:
 		root = self.tree.getroot()
 		query = self.db
+		query.commit()
 		eternals = dict(query.eternal.items())
 		root.set(
 			"db-schema-version", str(eternals.pop("_lisien_schema_version"))
@@ -230,7 +231,7 @@ class Exporter:
 		elif value is None:
 			return Element("None")
 		elif isinstance(value, bool):
-			return Element("bool", value="T" if value else "F")
+			return Element("bool", value="true" if value else "false")
 		elif isinstance(value, int):
 			return Element("int", value=str(value))
 		elif isinstance(value, float):
@@ -342,7 +343,7 @@ class Exporter:
 			)
 			kfel.append(rule_el)
 			if rule_name in bigs_kf and bigs_kf[rule_name]:
-				rule_el.set("big", "T")
+				rule_el.set("big", "true")
 			if (
 				rule_name in neighborhoods_kf
 				and neighborhoods_kf[rule_name] is not None
@@ -463,7 +464,7 @@ class Exporter:
 					node_el.set("rulebook", repr(val.pop("rulebook")))
 				char_el.append(node_el)
 				for k, v in val.items():
-					item_el = Element("dict_item", key=repr(k))
+					item_el = Element("dict-item", key=repr(k))
 					node_el.append(item_el)
 					item_el.append(cls._value_to_xml_el(v))
 		edge_val_kf: GraphEdgeValKeyframe = keyframe.get("edge_val", {})
@@ -486,7 +487,7 @@ class Exporter:
 						edge_el.set("rulebook", repr(val.pop("rulebook")))
 					char_el.append(edge_el)
 					for k, v in val.items():
-						item_el = Element("dict_item", key=repr(k))
+						item_el = Element("dict-item", key=repr(k))
 						edge_el.append(item_el)
 						item_el.append(Exporter._value_to_xml_el(v))
 
@@ -579,7 +580,7 @@ class Exporter:
 				"rule-big",
 				rule=rule,
 				tick=str(tick),
-				big="T" if big else "F",
+				big="true" if big else "false",
 			)
 		)
 
@@ -615,7 +616,7 @@ class Exporter:
 				character=repr(char),
 				name=repr(node),
 				tick=str(t),
-				exists="T" if ex else "F",
+				exists="true" if ex else "false",
 			)
 		)
 
@@ -642,7 +643,7 @@ class Exporter:
 				orig=repr(orig),
 				dest=repr(dest),
 				tick=str(t),
-				exists="T" if ex else "F",
+				exists="true" if ex else "false",
 			)
 		)
 
@@ -685,7 +686,7 @@ class Exporter:
 				"tick": str(t),
 			},
 		)
-		unit_el.set("is-unit", "T" if is_unit else "F")
+		unit_el.set("is-unit", "true" if is_unit else "false")
 		turn_el.append(unit_el)
 
 	@staticmethod
@@ -1037,7 +1038,7 @@ def game_path_to_etree(
 	game_path: str | os.PathLike, name: str | None = None
 ) -> ElementTree:
 	import json
-	from base64 import urlsafe_b64encode
+	from base64 import b64encode
 	from hashlib import blake2b
 
 	from .collections import FunctionStore
@@ -1057,7 +1058,7 @@ def game_path_to_etree(
 		modpy = modname + ".py"
 		if modpy in ls:
 			srchash = FunctionStore(os.path.join(game_path, modpy)).blake2b()
-			lisien_el.set(modname, urlsafe_b64encode(srchash).decode("utf-8"))
+			lisien_el.set(modname, b64encode(srchash).decode("utf-8"))
 	strings_dir = os.path.join(game_path, "strings")
 	if (
 		"strings" in ls
@@ -1079,9 +1080,7 @@ def game_path_to_etree(
 				Element(
 					"language",
 					code=fn,
-					blake2b=urlsafe_b64encode(langhash.digest()).decode(
-						"utf-8"
-					),
+					blake2b=b64encode(langhash.digest()).decode("utf-8"),
 				)
 			)
 	return game_history
