@@ -12,10 +12,12 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <https://www.gnu.org/licenses/>.
+import os
 import random
 from abc import ABC, abstractmethod
 from collections import defaultdict
 from contextlib import contextmanager
+from functools import cached_property
 from operator import attrgetter
 from threading import RLock
 from typing import Any, Mapping, MutableMapping, MutableSequence, Type
@@ -24,9 +26,9 @@ import networkx as nx
 from blinker import Signal
 
 from .cache import Cache, TurnEndDict, TurnEndPlanDict, UnitnessCache
+from .collections import CompositeDict, FunctionStore
 from .exc import NotInKeyframeError, TotalKeyError
-from .graph import DiGraph, Edge, Node
-from .types import CharName, Key, NodeName
+from .types import CharName, DiGraph, Edge, Key, Node, NodeName
 from .util import (
 	AbstractCharacter,
 	AbstractEngine,
@@ -34,10 +36,10 @@ from .util import (
 	SignalDict,
 	TimeSignalDescriptor,
 	getatt,
+	print_call_sig,
 	timer,
 )
 from .wrap import MutableMappingUnwrapper
-from .xcollections import CompositeDict
 
 
 class FacadeEntity(MutableMapping, Signal, ABC):
@@ -147,12 +149,12 @@ getname = attrgetter("name")
 class FacadeEntityMapping(MutableMappingUnwrapper, Signal, ABC):
 	"""Mapping that contains entities in a Facade.
 
-	All the entities are of the same type, ``facadecls``, possibly
+	All the entities are of the same type, ``cls``, possibly
 	being distorted views of entities of the type ``innercls``.
 
 	"""
 
-	facadecls: Type[FacadeEntity]
+	cls: Type[FacadeEntity]
 
 	@abstractmethod
 	def _get_inner_map(self):
@@ -163,8 +165,8 @@ class FacadeEntityMapping(MutableMappingUnwrapper, Signal, ABC):
 			for badkey in ("character", "engine", "name"):
 				if badkey in v:
 					del v[badkey]
-			return self.facadecls(self, k, **v)
-		return self.facadecls(self, v)
+			return self.cls(self, k, **v)
+		return self.cls(self, v)
 
 	engine = getatt("facade.engine")
 
@@ -208,12 +210,12 @@ class FacadeEntityMapping(MutableMappingUnwrapper, Signal, ABC):
 		ret = self._patch[k]
 		if ret is ...:
 			raise KeyError(k)
-		if type(ret) is not self.facadecls:
+		if type(ret) is not self.cls:
 			ret = self._patch[k] = self._make(k, ret)
 		return ret
 
 	def __setitem__(self, k, v):
-		if not isinstance(v, self.facadecls):
+		if not isinstance(v, self.cls):
 			v = self._make(k, v)
 		self._patch[k] = v
 		if self is not self.facade.node:
@@ -473,6 +475,9 @@ class FacadePlace(FacadeNode):
 		from .node import Place
 
 		super().__init__(mapping, real_or_name, **kwargs)
+		if isinstance(mapping, CharacterFacade):
+			mapping.place._patch[real_or_name] = self
+			return
 		if not isinstance(real_or_name, Place):
 			if real_or_name in mapping._patch:
 				real_or_name = mapping._patch[real_or_name]
@@ -585,7 +590,7 @@ class FacadePortal(FacadeEntity, Edge):
 
 
 class FacadePortalSuccessors(FacadeEntityMapping):
-	facadecls = FacadePortal
+	cls = FacadePortal
 	innercls: type
 
 	def __init__(self, facade, origname):
@@ -596,7 +601,7 @@ class FacadePortalSuccessors(FacadeEntityMapping):
 		self.orig = origname
 
 	def _make(self, k, v):
-		return self.facadecls(self, k, **v)
+		return self.cls(self, k, **v)
 
 	def _get_inner_map(self):
 		try:
@@ -608,7 +613,7 @@ class FacadePortalSuccessors(FacadeEntityMapping):
 
 
 class FacadePortalPredecessors(FacadeEntityMapping):
-	facadecls = FacadePortal
+	cls = FacadePortal
 	innercls: type
 
 	def __init__(self, facade, destname):
@@ -619,7 +624,7 @@ class FacadePortalPredecessors(FacadeEntityMapping):
 		self.dest = destname
 
 	def _make(self, k, v):
-		return self.facadecls(self.facade.portal[k], v)
+		return self.cls(self.facade.portal[k], v)
 
 	def _get_inner_map(self):
 		try:
@@ -629,6 +634,8 @@ class FacadePortalPredecessors(FacadeEntityMapping):
 
 
 class CharacterFacade(AbstractCharacter):
+	engine = getatt("db")
+
 	def __getstate__(self):
 		ports = {}
 		for o in self.portal:
@@ -744,19 +751,29 @@ class CharacterFacade(AbstractCharacter):
 			self.name, charn, noden, *self.engine._btt(), True
 		)
 
-	def __init__(self, character=None, engine=None):
-		self.character = character
-		if isinstance(engine, EngineFacade):
+	def __init__(self, engine=None, character=None, init_rulebooks=None):
+		if engine is None:
+			engine = self.db = EngineFacade(getattr(character, "db", None))
+		elif isinstance(engine, EngineFacade):
 			self.db = engine
 		else:
-			self.db = EngineFacade(engine or getattr(character, "db", None))
-		self._stat_map = self.StatMapping(self)
-		self._rb_patch = {}
-		if hasattr(character, "name"):
-			self.db.character._patch[character.name] = self
-			self._name = character.name
+			raise TypeError(
+				"Can't instantiate CharacterFacade with this for an engine",
+				engine,
+			)
+		if isinstance(character, AbstractCharacter):
+			self.character = character
+			if hasattr(character, "name"):
+				engine.character._patch[character.name] = self
+				self._name = character.name
+			else:
+				self._name = character
 		else:
 			self._name = character
+			self.character = None
+
+		self._stat_map = self.StatMapping(self)
+		self._rb_patch = {}
 
 	@property
 	def graph(self):
@@ -858,7 +875,7 @@ class CharacterFacade(AbstractCharacter):
 			return self.UnitMapping(self.character, item)
 
 	class ThingMapping(FacadeEntityMapping):
-		facadecls = FacadeThing
+		cls = FacadeThing
 		innercls: type
 
 		def __init__(self, facade, _=None):
@@ -882,7 +899,7 @@ class CharacterFacade(AbstractCharacter):
 			self.facade.node.patch(d)
 
 	class PlaceMapping(FacadeEntityMapping):
-		facadecls = FacadePlace
+		cls = FacadePlace
 		innercls: type
 
 		def __init__(self, facade, _=None):
@@ -945,6 +962,19 @@ class CharacterFacade(AbstractCharacter):
 			self.facade = facade
 			self._patch = {}
 
+		def copy(self):
+			d = {}
+			if hasattr(self.facade.character, "graph"):
+				for k, v in self.facade.character.graph.items():
+					if k not in self._patch:
+						d[k] = v
+					elif self._patch[k] is not ...:
+						d[k] = self._patch[k]
+			for k, v in self._patch.items():
+				if v is not ...:
+					d[k] = v
+			return d
+
 		def __iter__(self):
 			seen = set()
 			if hasattr(self.facade.character, "graph"):
@@ -985,7 +1015,7 @@ class CharacterFacade(AbstractCharacter):
 			return self._patch[k]
 
 		def __setitem__(self, k, v):
-			if self.facade.engine._planning:
+			if hasattr(self.facade, "engine") and self.facade.engine._planning:
 				self.facade.engine._planned[
 					self.facade.character.engine._curplan
 				][self.facade.engine.turn].append((self.facade.name, k, v))
@@ -995,6 +1025,24 @@ class CharacterFacade(AbstractCharacter):
 		def __delitem__(self, k):
 			self._patch[k] = ...
 
+		def __repr__(self):
+			toshow = {}
+			if hasattr(self.facade.character, "graph"):
+				for k in (
+					self._patch.keys() | self.facade.character.graph.keys()
+				):
+					if k in self._patch:
+						if self._patch[k] is not ...:
+							toshow[k] = self._patch[k]
+					elif k in self.facade.character.graph:
+						v = self.facade.character.graph[k]
+						if hasattr(v, "unwrap") and not hasattr(
+							v, "no_unwrap"
+						):
+							v = v.unwrap()
+						toshow[k] = v
+			return f"<StatMapping {toshow}>"
+
 	def apply(self):
 		"""Do all my changes for real in a batch"""
 		realchar = self.character
@@ -1052,6 +1100,26 @@ class EngineFacade(AbstractEngine):
 	portal_cls = FacadePortal
 	time = TimeSignalDescriptor()
 
+	@cached_property
+	def function(self):
+		return FunctionStore(None)
+
+	@cached_property
+	def method(self):
+		return FunctionStore(None)
+
+	@cached_property
+	def trigger(self):
+		return FunctionStore(None)
+
+	@cached_property
+	def prereq(self):
+		return FunctionStore(None)
+
+	@cached_property
+	def action(self):
+		return FunctionStore(None)
+
 	class FacadeUniversalMapping(Signal, MutableMapping):
 		def __init__(self, engine: AbstractEngine):
 			super().__init__()
@@ -1059,6 +1127,7 @@ class EngineFacade(AbstractEngine):
 			self.engine = engine
 			self._patch = {}
 			self._deleted = set()
+			self.closed = False
 
 		def _effective_keys(self):
 			if self.engine:
@@ -1115,11 +1184,9 @@ class EngineFacade(AbstractEngine):
 				raise KeyError("No character", key)
 			if key not in self._patch:
 				if realeng:
-					fac = CharacterFacade(
-						realeng.character[key], engine=realeng
-					)
+					fac = CharacterFacade(self.engine, realeng.character[key])
 				elif self.engine._mockup:
-					fac = CharacterFacade(key, engine=self.engine)
+					fac = CharacterFacade(self.engine, key)
 				else:
 					raise KeyError("No character", key)
 				self._patch[key] = fac
@@ -1199,6 +1266,34 @@ class EngineFacade(AbstractEngine):
 					setattr(self, alias, getattr(real, alias))
 				except AttributeError:
 					print(f"{alias} not implemented on {type(real)}")
+		elif mock:
+			import sys
+			from unittest.mock import MagicMock
+
+			from .collections import FunctionStore, StringStore
+
+			for funcs in ("function", "method", "trigger", "prereq", "action"):
+				setattr(self, funcs, FunctionStore(None))
+			self.string = StringStore({}, None)
+			for mockery in ("submit", "load_at"):
+				setattr(self, mockery, MagicMock())
+			if "kivy" in sys.modules:
+				from kivy.logger import Logger
+
+				logger = Logger
+			else:
+				from logging import getLogger
+
+				logger = getLogger("lisien")
+			for loggish in (
+				"log",
+				"debug",
+				"info",
+				"warning",
+				"error",
+				"critical",
+			):
+				setattr(self, loggish, getattr(logger, loggish))
 		self.closed = False
 		self._real = real
 		self._planning = False
@@ -1240,6 +1335,9 @@ class EngineFacade(AbstractEngine):
 			self.turn = 0
 			self.tick = 0
 
+	def handle(self, *args, **kwargs):
+		print_call_sig("handle", *args, **kwargs)
+
 	def _get_node(
 		self, char: AbstractCharacter | CharName, node: NodeName
 	) -> Node:
@@ -1273,6 +1371,25 @@ class EngineFacade(AbstractEngine):
 		self._branches_d[branch] = (parent, turn, tick, turn, tick)
 		self._extend_branch(branch, turn, tick)
 
+	def export(
+		self,
+		name: str | None,
+		path: str | os.PathLike | None = None,
+		indent: bool = True,
+	) -> None:
+		raise RuntimeError("Can't export facades")
+
+	@classmethod
+	def from_archive(
+		cls,
+		path: str | os.PathLike,
+		prefix: str | os.PathLike | None = ".",
+		**kwargs,
+	) -> AbstractEngine:
+		raise RuntimeError(
+			"Can't import archived Lisien games into facades. Use a regular Engine."
+		)
+
 	def load_at(self, branch: str, turn: int, tick: int) -> None:
 		pass
 
@@ -1325,7 +1442,7 @@ class EngineFacade(AbstractEngine):
 		edge: dict = None,
 		**kwargs,
 	):
-		self.character._patch[name] = char = CharacterFacade(name, self)
+		self.character._patch[name] = char = CharacterFacade(self, name)
 		if data:
 			char.become(data)
 		if node:
