@@ -338,7 +338,6 @@ def _make_edge_val_select(
 	graph: bytes,
 	orig: bytes,
 	dest: bytes,
-	idx: int,
 	stat: bytes,
 	branches: list[str],
 	mid_turn: bool,
@@ -350,7 +349,6 @@ def _make_edge_val_select(
 				tab.c.graph == graph,
 				tab.c.orig == orig,
 				tab.c.dest == dest,
-				tab.c.idx == idx,
 				tab.c.key == stat,
 				tab.c.branches.in_(branches),
 			)
@@ -360,7 +358,6 @@ def _make_edge_val_select(
 			tab.c.graph,
 			tab.c.orig,
 			tab.c.dest,
-			tab.c.idx,
 			tab.c.key,
 			tab.c.branch,
 			tab.c.turn,
@@ -371,7 +368,6 @@ def _make_edge_val_select(
 				tab.c.graph == graph,
 				tab.c.orig == orig,
 				tab.c.dest == dest,
-				tab.c.idx == idx,
 				tab.c.key == stat,
 				tab.c.branch.in_(branches),
 			)
@@ -380,7 +376,6 @@ def _make_edge_val_select(
 			tab.c.graph,
 			tab.c.orig,
 			tab.c.dest,
-			tab.c.idx,
 			tab.c.key,
 			tab.c.branch,
 			tab.c.turn,
@@ -394,7 +389,6 @@ def _make_edge_val_select(
 				tab.c.graph == ticksel.c.graph,
 				tab.c.orig == ticksel.c.orig,
 				tab.c.dest == ticksel.c.dest,
-				tab.c.idx == ticksel.c.idx,
 				tab.c.key == ticksel.c.key,
 				tab.c.branch == ticksel.c.branch,
 				tab.c.turn == ticksel.c.turn,
@@ -444,7 +438,6 @@ def _make_side_sel(
 			pack(entity.character.name),
 			pack(entity.origin.name),
 			pack(entity.destination.name),
-			0,
 			pack(stat),
 			branches,
 			mid_turn,
